@@ -14,7 +14,7 @@ use vars qw( @EXPORT_OK %EXPORT_TAGS );
 %EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
 
 use vars '$VERSION';
-$VERSION = '1.23';
+$VERSION = '1.25';
 my $CPERL = $^V =~ /c$/ ? 1 : 0;
 
 use vars '@Scalars';
@@ -469,12 +469,23 @@ use vars '@Barewords';
    ) : ()
   ),
   ($] >= 5.033007 ? qw(
-      try
-      catch
+     try
+     catch
     ) : ()
   ),
   ($] >= 5.035004 ? qw(
-      defer
+     defer
+    ) : ()
+  ),
+  ($] >= 5.035008 ? qw(
+     finally
+    ) : ()
+  ),
+  ($] >= 5.038000 ? qw(
+     ADJUST
+     class
+     field
+     method
     ) : ()
   ),
 );
